import { MyServerErrorHandler } from './serverErrorHandler';
import { catchError } from 'rxjs/operators';
import { Injectable } from '@angular/core';
import { environment } from 'src/environments/environment';
import { AppUser } from '../models/user/user.model';
import { Observable } from 'rxjs';
import { HttpClient } from '@angular/common/http';

@Injectable({
  providedIn: 'root',
})
export class UserService {
  constructor(
    private httpClient: HttpClient,
    private serverErrorHandler: MyServerErrorHandler
  ) {}


  geAllUsersService(): Observable<Array<AppUser>> {
    let users: Observable<Array<AppUser>> = this.httpClient.get<AppUser[]>(
      environment.USERS_SERVER + '/users'
    );
    return users;
  }

  createUserService(user: AppUser): Observable<any> {
    return this.httpClient
      .post<any>(environment.USERS_SERVER + '/users/', user)
      .pipe(catchError(this.serverErrorHandler.handleError));
  }

  deleteUserService(userID: number) {
    return this.httpClient
      .delete(environment.USERS_SERVER + '/users/' + userID)
      .pipe(catchError(this.serverErrorHandler.handleError));
  }

  getUserByID(userID: number): Observable<AppUser> {
    return this.httpClient
      .get<AppUser>(environment.USERS_SERVER + '/users/' + userID)
      .pipe(catchError(this.serverErrorHandler.handleError));
  }

  updateUserService(user: AppUser): Observable<AppUser> {
    let updatedUser: Observable<AppUser> = this.httpClient.put<AppUser>(
      environment.USERS_SERVER + '/users/' + user.userID,
      user
    );

    return updatedUser.pipe(catchError(this.serverErrorHandler.handleError));
  }
}
